"use client";

import Image from "next/image";

import { motion } from "framer-motion";
import { Circle } from "lucide-react";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { ProductDetailsBlogCategoryListData } from "@/utils/get-fake-data";

interface ProductDetailsBlogCategoryListClientProps {
	data: ProductDetailsBlogCategoryListData;
	locale: Locale;
}

export function ProductDetailsBlogCategoryListClient({
	data,
	locale,
}: ProductDetailsBlogCategoryListClientProps) {
	const isRTL = locale === "ar";

	return (
		<section className="relative">
			{/* Background Image */}
			<div className="absolute inset-0">
				<Image
					src="/bg-filter.jpeg"
					alt=""
					fill
					className="object-cover"
					priority
				/>
				<div className="absolute inset-0 bg-[#606676E5]" />
			</div>

			{/* Content */}
			<div className="container relative mx-auto px-12 py-16">
				<div className="grid gap-6 md:grid-cols-2 lg:grid-cols-4">
					{data.categories?.map((category, index) => (
						<motion.div
							key={category.id}
							initial={{ opacity: 0, y: 20 }}
							whileInView={{ opacity: 1, y: 0 }}
							viewport={{ once: true }}
							transition={{ delay: index * 0.1 }}
							className={cn(
								"flex flex-col items-center bg-white/95 p-6 text-center shadow-sm backdrop-blur-sm",
								category.isHighlighted &&
								"bg-gray-600/95 bg-[url('/wave.png')] bg-cover"
							)}
						>
							<Circle
								className={cn(
									"mb-4 h-12 w-12",
									category.isHighlighted
										? "text-[#828282]"
										: "text-custom-primary-accent"
								)}
								fill="currentColor"
							/>
							<h3
								className={cn(
									"mb-2 text-lg font-semibold",
									category.isHighlighted ? "text-white" : "text-gray-900",
									isRTL && "font-arabic"
								)}
							>
								{category.title?.[locale]}
							</h3>
							<p
								className={cn(
									"text-sm",
									category.isHighlighted ? "text-white/80" : "text-gray-600",
									isRTL && "font-arabic"
								)}
							>
								{category.description?.[locale]}
							</p>
						</motion.div>
					))}
				</div>
			</div>
		</section>
	);
}
